[tor-commits] [arm/packaging] Exporting dependencies from mirror

atagar at torproject.org atagar at torproject.org
Sun Jul 17 07:44:13 UTC 2011


commit 95d1ba0799ab05f3cd63c71edc89c49644cdeb83
Author: Damian Johnson <atagar at torproject.org>
Date:   Sun Jul 17 00:42:42 2011 -0700

    Exporting dependencies from mirror
    
    The cagraph wasn't being exported and torctl was coming from its source repo.
    Fetching both from the dependency mirror with sig checks instead.
---
 export.sh |   28 ++++++++++++++++++++++------
 1 files changed, 22 insertions(+), 6 deletions(-)

diff --git a/export.sh b/export.sh
index 79c6b38..ffa886a 100755
--- a/export.sh
+++ b/export.sh
@@ -1,7 +1,7 @@
 #!/bin/sh
 # Exports a copy of arm's release branch to the given location. This copy is
 # stripped of git metadata and includes a bundled copy of TorCtl. This accepts
 # an optional argument for where to place the export.
 
 if [ $# -lt 1 ]
   then exportDst="./arm"
@@ -19,15 +19,31 @@ fi
 mkdir $exportDst
 git archive --format=tar release | (cd $exportDst && tar xf -)
 
+# fetches our torctl and cagraph dependency
+wget --quiet http://www.atagar.com/arm/resources/deps/11-06-16/torctl.tar.gz
+sha256sum torctl.tar.gz
+echo "5460adb1394c368ba492cc33d6681618b3d3062b3f5f70b2a87520fc291701c3 <- expected"
+tar -C $exportDst/src -xzf torctl.tar.gz
+rm torctl.tar.gz
+
+wget --quiet http://www.atagar.com/arm/resources/deps/11-06-10/cagraph.tar.gz
+sha256sum cagraph.tar.gz
+echo "1439acd40ce016f4329deb216d86f36a749e4b8bf73a313a757396af6f95310d <- expected"
+tar -C $exportDst/src -xzf cagraph.tar.gz
+rm cagraph.tar.gz
+
+# the following installed torctl from its master repo rather than our
+# dependency mirror
+
 # fetches torctl to /tmp
-torctlDir="$(mktemp -d)"
-git clone git://git.torproject.org/pytorctl.git $torctlDir > /dev/null
+#torctlDir="$(mktemp -d)"
+#git clone git://git.torproject.org/pytorctl.git $torctlDir > /dev/null
 
 # exports torctl to the arm directory
-(cd $torctlDir && git archive --format=tar --prefix=TorCtl/ master) | (cd $exportDst/src && tar xf - 2> /dev/null)
+#(cd $torctlDir && git archive --format=tar --prefix=TorCtl/ master) | (cd $exportDst/src && tar xf - 2> /dev/null)
 
 # cleans up the temporary torctl repo
-rm -rf torctlDir
+#rm -rf torctlDir
 
 echo "arm exported to $exportDst"
 
@@ -1,7 +1,7 @@
 #!/bin/sh
 # Exports a copy of arm's release branch to the given location. This copy is
-# stripped of git metadata and includes a bundled copy of TorCtl. This accepts
-# an optional argument for where to place the export.
+# stripped of git metadata and includes a bundled copy of TorCtl and cagraph.
+# This accepts an optional argument for where to place the export.
 
 if [ $# -lt 1 ]



More information about the tor-commits mailing list